Skip to content

Commit

Permalink
msys2-runtime: bump to v3.5.5
Browse files Browse the repository at this point in the history
This corresponds to msys2/msys2-runtime#249.

Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de>
  • Loading branch information
dscho authored and lazka committed Dec 24, 2024
1 parent f1fc24c commit 01bdc2a
Show file tree
Hide file tree
Showing 48 changed files with 188 additions and 298 deletions.
2 changes: 1 addition & 1 deletion msys2-runtime/0001-Add-MSYS2-triplet.patch
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 51380ec75b3f11228cb680f3a4d71fc1957e5aec Mon Sep 17 00:00:00 2001
From bdad035f0baf6fa584ca10913e9948c0aba2970e Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 20:40:45 +0300
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From a116f418453dc6b272c3b58fcb1498790efccd6f Mon Sep 17 00:00:00 2001
From 900232bfff4076c483307b4af8f2bbf9b50a600f Mon Sep 17 00:00:00 2001
From: Kaleb Barrett <dev.ktbarrett@gmail.com>
Date: Sun, 14 Mar 2021 18:58:55 -0500
Subject: [PATCH 02/N] Fix msys library name in import libraries
Expand Down
34 changes: 17 additions & 17 deletions msys2-runtime/0003-Rename-dll-from-cygwin-to-msys.patch
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From f858c02bdb8d3444691dd99165718a1dd67ea753 Mon Sep 17 00:00:00 2001
From 585fadf7eab7cc83f6445adcd30b5c2b2e9357f8 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:09:17 +0300
Expand Down Expand Up @@ -277,7 +277,7 @@ index 9508f3e..3c40e0f 100644
w32len = cygheap->installation_key.Length / sizeof (WCHAR);
if (w32len
diff --git a/winsup/cygwin/exceptions.cc b/winsup/cygwin/exceptions.cc
index 3195d57..18271f5 100644
index a560a3f..8590929 100644
--- a/winsup/cygwin/exceptions.cc
+++ b/winsup/cygwin/exceptions.cc
@@ -526,14 +526,14 @@ int exec_prepared_command (PWCHAR command)
Expand All @@ -298,10 +298,10 @@ index 3195d57..18271f5 100644
break;
}
diff --git a/winsup/cygwin/fhandler/pipe.cc b/winsup/cygwin/fhandler/pipe.cc
index 6658a23..5d2fe12 100644
index 6a1ef03..7244fa4 100644
--- a/winsup/cygwin/fhandler/pipe.cc
+++ b/winsup/cygwin/fhandler/pipe.cc
@@ -727,7 +727,11 @@ fhandler_pipe::close ()
@@ -751,7 +751,11 @@ fhandler_pipe::close ()
return ret;
}

Expand All @@ -314,10 +314,10 @@ index 6658a23..5d2fe12 100644
/* Create a pipe, and return handles to the read and write ends,
just like CreatePipe, but ensure that the write end permits
diff --git a/winsup/cygwin/fhandler/pty.cc b/winsup/cygwin/fhandler/pty.cc
index fa6bf10..12a0ab3 100644
index 4f0f718..eb51c6d 100644
--- a/winsup/cygwin/fhandler/pty.cc
+++ b/winsup/cygwin/fhandler/pty.cc
@@ -927,7 +927,11 @@ fhandler_pty_slave::open (int flags, mode_t)
@@ -875,7 +875,11 @@ fhandler_pty_slave::open (int flags, mode_t)
pipe_reply repl;
DWORD len;

Expand All @@ -329,7 +329,7 @@ index fa6bf10..12a0ab3 100644
&cygheap->installation_key, get_minor ());
termios_printf ("dup handles via master control pipe %s", buf);
if (!CallNamedPipe (buf, &req, sizeof req, &repl, sizeof repl,
@@ -1206,7 +1210,11 @@ fhandler_pty_slave::reset_switch_to_nat_pipe (void)
@@ -1137,7 +1141,11 @@ fhandler_pty_slave::reset_switch_to_nat_pipe (void)
{
char pipe[MAX_PATH];
__small_sprintf (pipe,
Expand All @@ -341,7 +341,7 @@ index fa6bf10..12a0ab3 100644
&cygheap->installation_key, get_minor ());
pipe_request req = { GetCurrentProcessId () };
pipe_reply repl;
@@ -2090,7 +2098,11 @@ fhandler_pty_master::close ()
@@ -2021,7 +2029,11 @@ fhandler_pty_master::close ()
pipe_reply repl;
DWORD len;

Expand All @@ -353,7 +353,7 @@ index fa6bf10..12a0ab3 100644
&cygheap->installation_key, get_minor ());
acquire_output_mutex (mutex_timeout);
if (master_ctl)
@@ -2996,7 +3008,11 @@ fhandler_pty_master::setup ()
@@ -2927,7 +2939,11 @@ fhandler_pty_master::setup ()

/* Create master control pipe which allows the master to duplicate
the pty pipe handles to processes which deserve it. */
Expand All @@ -365,7 +365,7 @@ index fa6bf10..12a0ab3 100644
&cygheap->installation_key, unit);
master_ctl = CreateNamedPipe (buf, PIPE_ACCESS_DUPLEX
| FILE_FLAG_FIRST_PIPE_INSTANCE,
@@ -3880,7 +3896,11 @@ fhandler_pty_slave::transfer_input (tty::xfer_dir dir, HANDLE from, tty *ttyp,
@@ -3816,7 +3832,11 @@ fhandler_pty_slave::transfer_input (tty::xfer_dir dir, HANDLE from, tty *ttyp,
{
char pipe[MAX_PATH];
__small_sprintf (pipe,
Expand Down Expand Up @@ -436,7 +436,7 @@ index 1e4cf98..b77598b 100644
} \
} \
diff --git a/winsup/cygwin/include/cygwin/version.h b/winsup/cygwin/include/cygwin/version.h
index 0f87fbc..2e624a9 100644
index fb821a6..1c68287 100644
--- a/winsup/cygwin/include/cygwin/version.h
+++ b/winsup/cygwin/include/cygwin/version.h
@@ -502,7 +502,11 @@ details. */
Expand Down Expand Up @@ -617,7 +617,7 @@ index 43b5803..db1d5c8 100644
ts.SourceIdentifier.LowPart = kerberos_auth ? 0x0105 : 0x0106;

From b084abe0ec93354984d37d0ec09fab39984d1e90 Mon Sep 17 00:00:00 2001
From d076660c2d88cc79897b73b53134b040d623c547 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:17:46 +0300
Expand Down Expand Up @@ -1086,7 +1086,7 @@ index 1802e76..84851a1 100644

/* Cover functions to the path conversion routines.
diff --git a/winsup/cygwin/spawn.cc b/winsup/cygwin/spawn.cc
index d01f678..845121f 100644
index f5a4b91..902cef8 100644
--- a/winsup/cygwin/spawn.cc
+++ b/winsup/cygwin/spawn.cc
@@ -292,6 +292,27 @@ child_info_spawn::worker (const char *prog_arg, const char *const *argv,
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From f16038529ae929ad0371de5b7a8ba651b1888e29 Mon Sep 17 00:00:00 2001
From 35a477b5cd63373397b0dc713de7b95d610ad300 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:29:01 +0300
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 6393488c9d7048ba7081374b806397c74ee2def6 Mon Sep 17 00:00:00 2001
From 41ed62e6f51e80b764de465ab9f9045552107813 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:45:06 +0300
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 06ea20e4eceef17d67a404d670b439e87f282450 Mon Sep 17 00:00:00 2001
From 8096583fac66461dbe1414f210d998a3087c1ecc Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:47:21 +0300
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 222fd37c0b4f4502a0dd67ab3369fb630ded3420 Mon Sep 17 00:00:00 2001
From 0ba54e8cc1940f94e9cde6b6c74cb6a8fb240d56 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:48:54 +0300
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 41e8ada0d105959dfd3a1665875a09b64ceb06a3 Mon Sep 17 00:00:00 2001
From e28b7422e206f39202a9f1f840a84cd7a59287c2 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 21:50:55 +0300
Expand All @@ -10,7 +10,7 @@ Strace is a Windows program so MSYS2 will convert all arguments and environment
1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/winsup/cygwin/spawn.cc b/winsup/cygwin/spawn.cc
index 845121f..ace43db 100644
index 902cef8..d7affaa 100644
--- a/winsup/cygwin/spawn.cc
+++ b/winsup/cygwin/spawn.cc
@@ -545,11 +545,13 @@ child_info_spawn::worker (const char *prog_arg, const char *const *argv,
Expand Down
2 changes: 1 addition & 1 deletion msys2-runtime/0010-strace.cc-Don-t-set-MSYS-noglob.patch
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 766e55c1bea155c16b8fe28506b86f661c292dc6 Mon Sep 17 00:00:00 2001
From 4a24304b8b1463097d2532f327eb9e44f272a303 Mon Sep 17 00:00:00 2001
From: Ray Donnelly <mingw.android@gmail.com>
Date: Sun, 23 Aug 2015 20:47:30 +0100
Subject: [PATCH 10/N] strace.cc: Don't set MSYS=noglob
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 4f01c3f5c7c3201c46d682f378d8b1ddbd7a0d87 Mon Sep 17 00:00:00 2001
From b3a4a5bd44740716566e221dba0625e117d92ab4 Mon Sep 17 00:00:00 2001
From: Ray Donnelly <mingw.android@gmail.com>
Date: Fri, 21 Aug 2015 09:52:47 +0100
Subject: [PATCH 11/N] Add debugging for strace make_command_line
Expand Down
2 changes: 1 addition & 1 deletion msys2-runtime/0012-strace-quiet-be-really-quiet.patch
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From d43f1eebf2fed9c1c9321eecae12b4830fc19b92 Mon Sep 17 00:00:00 2001
From f8c098028cde692958bfed365c8877a038860d6c Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Wed, 17 May 2017 18:13:32 +0200
Subject: [PATCH 12/N] strace --quiet: be *really* quiet
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 0053f7b38e025ef1358958232e0231c455cc2bc3 Mon Sep 17 00:00:00 2001
From c4d9d83ede9abf0c47949bd3ac6f91fd3325dc64 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=D0=90=D0=BB=D0=B5=D0=BA=D1=81=D0=B5=D0=B8=CC=86=20=D0=9F?=
=?UTF-8?q?=D0=B0=D0=B2=D0=BB=D0=BE=D0=B2?= <alexey.pawlow@gmail.com>
Date: Sun, 14 Apr 2019 22:13:51 +0300
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 1e8a891f5ec4bb1b96f18c07b7180999c14b8ce0 Mon Sep 17 00:00:00 2001
From 1c5a6e869c61b66c9924c38a9948413667e3ee44 Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Tue, 8 Nov 2022 16:24:20 +0100
Subject: [PATCH 14/N] When converting to a Unix path, avoid double trailing
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 673065dd1eeedc82dda43aaeb435040be2703ea4 Mon Sep 17 00:00:00 2001
From 8b5e9b55a1021d73b91a49cc640f2817394a5bb5 Mon Sep 17 00:00:00 2001
From: Christoph Reiter <reiter.christoph@gmail.com>
Date: Sun, 20 Nov 2022 13:57:36 +0100
Subject: [PATCH 15/N] msys2_path_conv: pass PC_NOFULL to path_conv
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From e1db14849f307053cf0728f385fd8e2c884b4d03 Mon Sep 17 00:00:00 2001
From b09fb7fd5a22f32b58938da80aff0d02193c64c2 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=EB=A7=88=EB=88=84=EC=97=98?= <nalla@hamal.uberspace.de>
Date: Wed, 17 Jun 2015 09:30:41 +0200
Subject: [PATCH 16/N] path-conversion: Introduce ability to switch off
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From f6e516da390ea3f729132274db1303ab95a61e7c Mon Sep 17 00:00:00 2001
From b2391806dbe3f72235fe1431940631f26757a2f0 Mon Sep 17 00:00:00 2001
From: Ray Donnelly <mingw.android@gmail.com>
Date: Fri, 21 Aug 2015 12:52:09 +0100
Subject: [PATCH 17/N] dcrt0.cc: Untangle allow_glob from winshell
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 1059fbbdea827dc369d76eb59d2c2bf087faa84b Mon Sep 17 00:00:00 2001
From 1e94f3ee1dc663bc0292324bef65be88c74c30fa Mon Sep 17 00:00:00 2001
From: Ray Donnelly <mingw.android@gmail.com>
Date: Mon, 24 Aug 2015 00:48:06 +0100
Subject: [PATCH 18/N] dcrt0.cc (globify): Don't quote literal strings
Expand Down
2 changes: 1 addition & 1 deletion msys2-runtime/0019-Add-debugging-for-build_argv.patch
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From f8da08fd7e82b038fe2e278153bc6545dae232b0 Mon Sep 17 00:00:00 2001
From e6c5e3ec30c0c99d797b69314d5721eaca2d752b Mon Sep 17 00:00:00 2001
From: Ray Donnelly <mingw.android@gmail.com>
Date: Fri, 21 Aug 2015 12:18:52 +0100
Subject: [PATCH 19/N] Add debugging for build_argv
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 03d6fe120a36c805008cc611ad140e2a222dc8b0 Mon Sep 17 00:00:00 2001
From d44fc10030e02b339fe4253b2cf3d6d3e72e5c92 Mon Sep 17 00:00:00 2001
From: Ray Donnelly <mingw.android@gmail.com>
Date: Sun, 10 Apr 2016 21:47:41 +0100
Subject: [PATCH 20/N] environ.cc: New facility/environment variable
Expand Down Expand Up @@ -98,7 +98,7 @@ index d52deba..c4dbe02 100644
extern inline void
transform_chars (PUNICODE_STRING upath, USHORT start_idx)
diff --git a/winsup/cygwin/miscfuncs.cc b/winsup/cygwin/miscfuncs.cc
index 767384f..160c996 100644
index 4220f62..5446654 100644
--- a/winsup/cygwin/miscfuncs.cc
+++ b/winsup/cygwin/miscfuncs.cc
@@ -311,6 +311,26 @@ NT_readline::gets ()
Expand Down Expand Up @@ -141,7 +141,7 @@ index b1a088a..39819dc 100644
{
/* Since we've got regex linked we should maybe switch to that, but
diff --git a/winsup/cygwin/spawn.cc b/winsup/cygwin/spawn.cc
index ace43db..57231b3 100644
index d7affaa..5b3cbeb 100644
--- a/winsup/cygwin/spawn.cc
+++ b/winsup/cygwin/spawn.cc
@@ -293,8 +293,7 @@ child_info_spawn::worker (const char *prog_arg, const char *const *argv,
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 90d66ee649c0b2f265583942352725e9fac74aa9 Mon Sep 17 00:00:00 2001
From 98c164175f51d79bc91caaad905b386e8d45615b Mon Sep 17 00:00:00 2001
From: SquallATF <squallatf@gmail.com>
Date: Mon, 10 Sep 2018 11:32:18 +0300
Subject: [PATCH 21/N] Fix native symbolic link spawn passing wrong arg0
Expand All @@ -8,7 +8,7 @@ Subject: [PATCH 21/N] Fix native symbolic link spawn passing wrong arg0
1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/winsup/cygwin/spawn.cc b/winsup/cygwin/spawn.cc
index 57231b3..9d2a016 100644
index 5b3cbeb..b97c6da 100644
--- a/winsup/cygwin/spawn.cc
+++ b/winsup/cygwin/spawn.cc
@@ -50,7 +50,7 @@ perhaps_suffix (const char *prog, path_conv& buf, int& err, unsigned opt)
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 7b84fed8f06744f2d308c6ace42275b4941cb90c Mon Sep 17 00:00:00 2001
From d12ab6d59cbc9473f29afdf2bd12318a1a5f09ea Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Tue, 19 May 2020 13:49:37 +0200
Subject: [PATCH 22/N] Introduce the `enable_pcon` value for `MSYS`
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 6f87e23bae318aa95fefe6d40a6630901d91c2aa Mon Sep 17 00:00:00 2001
From 865ad5d64ececf728b8027043684b5e2a4e9ae2a Mon Sep 17 00:00:00 2001
From: Christoph Reiter <reiter.christoph@gmail.com>
Date: Fri, 5 Jun 2020 20:09:11 +0200
Subject: [PATCH 23/N] popen: call /usr/bin/sh instead of /bin/sh
Expand All @@ -17,10 +17,10 @@ in this scenario, so this maybe should be extended to all of them.
1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/winsup/cygwin/syscalls.cc b/winsup/cygwin/syscalls.cc
index ed564c8..fe4b9cb 100644
index 2d7071b..e584e96 100644
--- a/winsup/cygwin/syscalls.cc
+++ b/winsup/cygwin/syscalls.cc
@@ -4423,7 +4423,7 @@ popen (const char *command, const char *in_type)
@@ -4425,7 +4425,7 @@ popen (const char *command, const char *in_type)
fcntl (stdchild, F_SETFD, stdchild_state | FD_CLOEXEC);

/* Start a shell process to run the given command without forking. */
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 4dd6aad8634373e09d218628eea91f02840e014a Mon Sep 17 00:00:00 2001
From 080e2b0f6abe07f4eab5e44bf689f3f48efc7b61 Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Wed, 12 Aug 2020 12:22:38 +0200
Subject: [PATCH 24/N] Expose full command-lines to other Win32 processes by
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 6ef58ed329d4d1b59091471a575a5c0af3ac192d Mon Sep 17 00:00:00 2001
From 9f45f58388505943f06fff68c8695dd5f17d2a67 Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Mon, 16 Apr 2018 14:59:39 +0200
Subject: [PATCH 25/N] Add a helper to obtain a function's address in
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 38a8880717c5431c2c4d596dc0aa22c6906059f9 Mon Sep 17 00:00:00 2001
From f6f7e2c92880e56d0c4b8712630941aa72257f4d Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Fri, 20 Mar 2015 09:56:28 +0000
Subject: [PATCH 26/N] Emulate GenerateConsoleCtrlEvent() upon Ctrl+C
Expand Down Expand Up @@ -93,7 +93,7 @@ Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de>
create mode 100644 winsup/cygwin/include/cygwin/exit_process.h

diff --git a/winsup/cygwin/exceptions.cc b/winsup/cygwin/exceptions.cc
index 18271f5..f6b6255 100644
index 8590929..469052a 100644
--- a/winsup/cygwin/exceptions.cc
+++ b/winsup/cygwin/exceptions.cc
@@ -29,6 +29,7 @@ details. */
Expand All @@ -104,7 +104,7 @@ index 18271f5..f6b6255 100644

/* Define macros for CPU-agnostic register access. The _CX_foo
macros are for access into CONTEXT, the _MC_foo ones for access into
@@ -1598,10 +1599,25 @@ exit_sig:
@@ -1605,10 +1606,25 @@ exit_sig:
dosig:
if (have_execed)
{
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From b9d1fadafe592ced300e80ddfa1f6358a46ecdb5 Mon Sep 17 00:00:00 2001
From 86cd50d151515388c06d5f0e860cf002480d94fd Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Fri, 20 Mar 2015 10:01:50 +0000
Subject: [PATCH 27/N] kill: kill Win32 processes more gently
Expand All @@ -13,7 +13,7 @@ Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de>
1 file changed, 15 insertions(+), 4 deletions(-)

diff --git a/winsup/utils/kill.cc b/winsup/utils/kill.cc
index fb45e4c..28473d1 100644
index bcabcd4..31ad57a 100644
--- a/winsup/utils/kill.cc
+++ b/winsup/utils/kill.cc
@@ -17,6 +17,7 @@ details. */
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
diff --git a/winsup/cygwin/syscalls.cc b/winsup/cygwin/syscalls.cc
index 9d88b60..ed564c8 100644
index 11033bc..2d7071b 100644
--- a/winsup/cygwin/syscalls.cc
+++ b/winsup/cygwin/syscalls.cc
@@ -339,7 +339,7 @@ try_to_bin (path_conv &pc, HANDLE &fh, ACCESS_MASK access, ULONG flags)
Expand All @@ -626,15 +626,15 @@ index 9d88b60..ed564c8 100644
{
/* Create unique filename. Start with a dot, followed by "cyg"
transposed into the Unicode low surrogate area (U+dc00) on file
systems supporting Unicode (except Samba), followed by the inode
number in hex, followed by a path hash in hex. The combination
transposed to the Unicode private use area in the U+f700 area
on file systems supporting Unicode (except Samba), followed by
the inode number in hex, followed by a path hash in hex. The
@@ -347,7 +347,7 @@ try_to_bin (path_conv &pc, HANDLE &fh, ACCESS_MASK access, ULONG flags)
RtlAppendUnicodeToString (&recycler,
(pc.fs_flags () & FILE_UNICODE_ON_DISK
&& !pc.fs_is_samba ())
- ? L".\xdc63\xdc79\xdc67" : L".cyg");
+ ? L".\xdc6d\xdc73\xdc79\xdc73" : L".msys");
- ? L".\xf763\xf779\xf767" : L".cyg");
+ ? L".\xf76d\xf773\xf779\xf773" : L".msys");
pfii = (PFILE_INTERNAL_INFORMATION) infobuf;
status = NtQueryInformationFile (fh, &io, pfii, sizeof *pfii,
FileInternalInformation);
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
@@ -339,7 +339,7 @@ try_to_bin (path_conv &pc, HANDLE &fh, ACCESS_MASK access, ULONG flags)
Expand All @@ -626,15 +626,15 @@ index 9d88b60..ed564c8 100644
{
- /* Create unique filename. Start with a dot, followed by "cyg"
+ /* Create unique filename. Start with a dot, followed by "msys"
transposed into the Unicode low surrogate area (U+dc00) on file
systems supporting Unicode (except Samba), followed by the inode
From 715f6ce8910a7ccfedb90a021ead592ec8e62be7 Mon Sep 17 00:00:00 2001
From 4b228ef2e491970f967aaed3339ce807c282d73c Mon Sep 17 00:00:00 2001
From: Jeremy Drake <github@jdrake.com>
Date: Thu, 22 Jul 2021 11:59:16 -0700
Subject: [PATCH 28/N] Cygwin: make option for native inner link handling.
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From abeeb31b2b49921b01d4ce7cfbac82dfa6c292bb Mon Sep 17 00:00:00 2001
From 6e0c3b56c7c232ad7a20a2a93fd1679ca58e4a2c Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Mon, 8 Nov 2021 14:20:07 +0100
Subject: [PATCH 29/N] docs: skip building texinfo and PDF files
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From fbe8ae30a3ea6af5541cf9f412f601bca963aa6f Mon Sep 17 00:00:00 2001
From ecf50e64ce03f2840dc08605e087c2f3f361c14b Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Mon, 8 Nov 2021 16:22:57 +0100
Subject: [PATCH 30/N] install-libs: depend on the "toollibs"
Expand Down
2 changes: 1 addition & 1 deletion msys2-runtime/0031-POSIX-ify-the-SHELL-variable.patch
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 38abc7cfff7f580c7563b90dc799ae28e6338bf5 Mon Sep 17 00:00:00 2001
From 8cb4ff2c0ecb196f77686ada7f3c165b7183d380 Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Mon, 23 Nov 2015 20:03:11 +0100
Subject: [PATCH 31/N] POSIX-ify the SHELL variable
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 9c758e8f9cb30d58e5499eed5154a4266d335be1 Mon Sep 17 00:00:00 2001
From 1f6020c6bfa115ac641881aadeece5ee40eb02bc Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Tue, 21 Mar 2017 13:18:38 +0100
Subject: [PATCH 32/N] Handle ORIGINAL_PATH just like PATH
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From 312f7660cc8f4690f30327994212ec890df09e28 Mon Sep 17 00:00:00 2001
From 79e3880244c30efecd2221a0bc90d452a62d873e Mon Sep 17 00:00:00 2001
From: Christoph Reiter <reiter.christoph@gmail.com>
Date: Sun, 3 Jul 2022 22:39:32 +0200
Subject: [PATCH 33/N] uname: allow setting the system name to CYGWIN
Expand Down
Original file line number Diff line number Diff line change
@@ -1,4 +1,4 @@
From e19af2018e02eb7365c931d63748b2bad021855e Mon Sep 17 00:00:00 2001
From ef59c45434b5296d18f7aab785ca2db13f1be8d7 Mon Sep 17 00:00:00 2001
From: Johannes Schindelin <johannes.schindelin@gmx.de>
Date: Wed, 18 Feb 2015 12:32:17 +0000
Subject: [PATCH 34/N] Pass environment variables with empty values
Expand Down
Loading

0 comments on commit 01bdc2a

Please sign in to comment.